==> super_scad-0.2.0.tar.gz: super_scad-0.2.0/super_scad/other/Render.py <==
from super_scad.private.PrivateSingleChildScadCommand import PrivateSingleChildScadCommand
from super_scad.ScadObject import ScadObject


class Render(PrivateSingleChildScadCommand):
    """
    Forces the generation of a mesh even in preview mode. This is useful in certain situations, e.g. when the boolean
    operations become too slow to track. Render can also be used (typically in conjunction with convexity) to
    avoid/workaround preview artifacts. See
    https://en.wikibooks.org/wiki/OpenSCAD_User_Manual/Other_Language_Features#render.
    """

    # ------------------------------------------------------------------------------------------------------------------
    def __init__(self, *, convexity: int | None = None, child: ScadObject):
        """
        Object constructor.

        :param convexity: Number of "inward" curves, i.e. expected number of path crossings of an arbitrary line through
                          the child object.
        """
        PrivateSingleChildScadCommand.__init__(self, command='render', args=locals(), child=child)

    # ------------------------------------------------------------------------------------------------------------------
    @property
    def convexity(self) -> int | None:
        """
        Returns the number of "inward" curves, i.e. expected number of path crossings of an arbitrary line through the
        child object.
        """
        return self._args.get('convexity')

# ----------------------------------------------------------------------------------------------------------------------

==> super_scad-0.7.1.tar.gz: super_scad-0.7.1/super_scad/other/Render.py <==
from super_scad.private.PrivateSingleChildOpenScadCommand import PrivateSingleChildOpenScadCommand
from super_scad.scad.ScadWidget import ScadWidget


class Render(PrivateSingleChildOpenScadCommand):
    """
    Forces the generation of a mesh even in preview mode. This is useful in certain situations, e.g. when the boolean
    operations become too slow to track. Render can also be used (typically in conjunction with convexity) to
    avoid/workaround preview artifacts. See
    https://en.wikibooks.org/wiki/OpenSCAD_User_Manual/Other_Language_Features#render.
    """

    # ------------------------------------------------------------------------------------------------------------------
    def __init__(self,
                 *,
                 convexity: int | None = None,
                 child: ScadWidget):
        """
        Object constructor.

        :param convexity: Number of "inward" curves, i.e. expected number of path crossings of an arbitrary line through
                          the child widget.
        """
        PrivateSingleChildOpenScadCommand.__init__(self, command='render', args=locals(), child=child)

    # ------------------------------------------------------------------------------------------------------------------
    @property
    def convexity(self) -> int | None:
        """
        Returns the number of "inward" curves, i.e. expected number of path crossings of an arbitrary line through the
        child object.
        """
        return self._args.get('convexity')

# ----------------------------------------------------------------------------------------------------------------------
